@@ -14,11 +14,12 @@
 ##      documentation and/or other materials provided with the distribution.
 
 use strict;
+use warnings;
 
 sub control_ihave {
     my (
-        $par, $sender, $replyto, $site, $action, $log, $approved,
-        $article,
+        $par_unused, $sender, $replyto_unused, $site, $action, $log,
+        $approved_unused, $article,
     ) = @_;
     my @body = split(/\r?\n/, $article->stringify_body);
 
