@@ -1,13 +1,27 @@
 ##  Perl module which sets up any and all variables that an
 ##  INN Perl script might need.
+##
+##  Originally written by James Brister in 1996 as innshellvars.pl, and
+##  converted to this INN::Config Perl module by Julien Élie in 2007.
+##
+##  Various bug fixes, code and documentation improvements since then
+##  in 2007-2011, 2013, 2018, 2021, 2022, 2024.
 
 package INN::Config;
 
+use strict;
 use warnings;
 use Exporter;
 
+# Variables dynamically declared from innconfval, and used in this package.
+use vars qw(
+    $ovmethod $patharchive $patharticles $pathbin $pathcontrol $pathdb
+    $pathetc $pathfilter $pathincoming $pathlog $pathnews $pathoutgoing
+    $pathoverview $pathrun $pathspool $pathtmp $runasuser $runasgroup
+);
+
 our @ISA = qw(Exporter);
-our $VERSION = '2.7.2';
+our $VERSION = '2.7.3';
 
 ##  First, two necessary variables (listed below in @DIRVAR).
 our $prefix = '/usr';
@@ -15,7 +29,7 @@ our $exec_prefix = "${prefix}";
 
 ##  Then, process the variables provided by innconfval.
 my @INNCONFVAR = ();
-my @values = `${exec_prefix}/bin/innconfval -p`;
+my @values = qx(${exec_prefix}/bin/innconfval -p);
 foreach my $line (@values) {
     eval 'our ' . $line;
     if ($line =~ /^(.*?) = /m) {
@@ -24,11 +38,12 @@ foreach my $line (@values) {
 }
 
 ##  Paths of useful directories.
-my @DIRVAR = qw($prefix $exec_prefix $newshome $home $newslib
-  $newsbin $controlprogs $newslbin $newsetc $spooldir
-  $archivedir $spool $incoming $spoolnews $badnews
-  $batch $overviewdir $most_logs $locks $innddir $tmpdir
-  $spooltemp $path);
+my @DIRVAR = qw(
+    $prefix $exec_prefix $newshome $home $newslib $newsbin $controlprogs
+    $newslbin $newsetc $spooldir $archivedir $spool $incoming $spoolnews
+    $badnews $batch $overviewdir $most_logs $locks $innddir $tmpdir
+    $spooltemp $path
+);
 our $newshome = $pathnews;
 our $home = $pathnews;
 our $newslib = "${exec_prefix}/lib";
@@ -53,10 +68,11 @@ our $path = $ENV{'PATH'} || '';
 $path = "${newslbin}:${newsbin}:${path}:/bin:/usr/bin";
 
 ##  Paths of useful files.
-my @FILESVAR = qw($active $activetimes $newactive $oldactive
-  $history $newsgroups $ctlfile $ctlwatch $localgroups
-  $newsfeeds $path_motd_innd $path_motd_nnrpd $path_motd
-  $expirectl $errlog $log);
+my @FILESVAR = qw(
+    $active $activetimes $newactive $oldactive $history $newsgroups $ctlfile
+    $ctlwatch $localgroups $newsfeeds $path_motd_innd $path_motd_nnrpd
+    $path_motd $expirectl $errlog $log
+);
 our $active = "${pathdb}/active";
 our $activetimes = "${pathdb}/active.times";
 our $newactive = "${pathdb}/active.tmp";
@@ -75,10 +91,11 @@ our $errlog = "${most_logs}/errlog";
 our $log = "${most_logs}/news";
 
 ##  Paths of useful programs.
-my @PROGVAR = qw($inews $innconfval $innd $inndf $innwatch
-  $rnews $perl_startup_innd $perl_filter_innd $perl_filter_nnrpd
-  $python_filter_innd $path_python_inn_module $path_tcl_startup
-  $path_tcl_filter);
+my @PROGVAR = qw(
+    $inews $innconfval $innd $inndf $innwatch $rnews $perl_startup_innd
+    $perl_filter_innd $perl_filter_nnrpd $python_filter_innd
+    $path_python_inn_module $path_tcl_startup $path_tcl_filter
+);
 our $inews = "${newsbin}/inews";
 our $innconfval = "${newsbin}/innconfval";
 our $innd = "${newsbin}/innd";
@@ -94,8 +111,10 @@ our $path_tcl_startup = "$pathfilter/startup.tcl";
 our $path_tcl_filter = "$pathfilter/filter.tcl";
 
 ##  Paths of lock/PID/status files.
-my @LOCKVAR = qw($daily $newscontrol $nntpconnect $serverpid
-  $innwstatus $watchpid $tempsock $tempsockdir);
+my @LOCKVAR = qw(
+    $daily $newscontrol $nntpconnect $serverpid $innwstatus $watchpid
+    $tempsock $tempsockdir
+);
 our $daily = "${locks}/LOCK.news.daily";
 our $newscontrol = "${innddir}/control";
 our $nntpconnect = "${innddir}/nntpin";
@@ -106,8 +125,10 @@ our $watchpid = "${innddir}/innwatch.pid";
 (our $tempsockdir = "${innddir}/ctlinndXXXXXX") =~ s!/[^/]*$!!;
 
 ##  Paths of external used programs.
-my @EXTPROGVAR = qw($awk $egrep $gpgv $gpg $perl $pgp $sed
-  $sort $getftp $uustat $uux);
+my @EXTPROGVAR = qw(
+    $awk $egrep $gpgv $gpg $perl $pgp $sed $sort $getftp $gethttp $uustat
+    $uux
+);
 our $awk = 'gawk';
 our $egrep = '/usr/bin/grep -E';
 our $gpgv = '/usr/bin/gpgv';
@@ -117,12 +138,12 @@ our $pgp = '';
 our $sed = '/usr/bin/sed';
 our $sort = '/usr/bin/sort';
 our $getftp = "${exec_prefix}/bin/simpleftp";
+our $gethttp = "${exec_prefix}/bin/simpleftp";
 our $uustat = '';
 our $uux = 'uux';
 
 ##  Paths of external used compressors.
-my @EXTCOMPVAR = qw($bzip2 $compress $gzip $uncompress
-  $log_compress $z);
+my @EXTCOMPVAR = qw($bzip2 $compress $gzip $uncompress $log_compress $z);
 our $bzip2 = '/usr/bin/bzip2';
 our $compress = 'compress';
 our $gzip = '/usr/bin/gzip';
@@ -131,8 +152,10 @@ our $log_compress = '/usr/bin/gzip';
 our $z = '.gz';
 
 ##  Set up some useful system file information.
-my @SYSVAR = qw($newsmaster $newsuser $newsgroup
-  $filemode $inewsmode $rnewsmode $umask $syslog_facility);
+my @SYSVAR = qw(
+    $newsmaster $newsuser $newsgroup $filemode $inewsmode $rnewsmode $umask
+    $syslog_facility
+);
 our $newsmaster = 'usenet';
 our $newsuser = ${runasuser};
 our $newsgroup = ${runasgroup};
@@ -178,10 +201,9 @@ umask 02;
 #>>V
 
 ##  This array will contain what it is possible to export.
-our @EXPORT_OK = (
-    @INNCONFVAR, @DIRVAR, @FILESVAR, @PROGVAR,
-    @LOCKVAR, @EXTPROGVAR, @EXTCOMPVAR, @SYSVAR, @PARAMVAR,
-    qw($VERSION),
+our @EXPORT_OK = qw(
+    @INNCONFVAR @DIRVAR @FILESVAR @PROGVAR @LOCKVAR @EXTPROGVAR @EXTCOMPVAR
+    @SYSVAR @PARAMVAR $VERSION
 );
 
 ##  Load another script that can override or add variables.
@@ -194,6 +216,8 @@ if (-x "${pathetc}/innshellvars.pl.local") {
 
 __END__
 
+=encoding utf-8
+
 =head1 NAME
 
 INN::Config - Export all the variables an INN Perl script might need
@@ -267,7 +291,7 @@ module.
 
 F<innshellvars.pl> was written by James Brister <brister@vix.com>
 for InterNetNews in 1996.  It was converted to the INN::Config Perl
-module by Julien Elie in 2007.
+module by Julien Élie in 2007.
 
 =head1 SEE ALSO
 
